`jqviz` will let you iterate over a `jq` string in your browser.

To use, you must already have [jq] installed.

```bash
jqviz my_test_file.json
```

To quit, hit the "quit" button in the browser window that opens, or `cmd-C` in the terminal window.


[jq]: https://stedolan.github.io/jq/